ShapeType

Enum ShapeType 

#[non_exhaustive]
pub enum ShapeType {
Show 18 variants Boolean, Byte, Short, Integer, Long, Float, Double, BigInteger, BigDecimal, String, Blob, Timestamp, Document, List, Map, Structure, Union, Member,
}
Enumeration of Smithy shape types.

This represents the core shape types from the Smithy specification, including simple types, aggregate types, and the special member type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Boolean

Boolean type



Byte

8-bit signed integer



Short

16-bit signed integer



Integer

32-bit signed integer



Long

64-bit signed integer



Float

32-bit floating point



Double

64-bit floating point



BigInteger

Arbitrary precision integer



BigDecimal

Arbitrary precision decimal



String

UTF-8 string



Blob

Binary data



Timestamp

Timestamp



Document

Document type



List

List type



Map

Map type



Structure

Structure type



Union

Union type



Member

Member shape

Implementations

Source

impl ShapeType

pub fn is_simple(&self) -> bool

Returns true if this is a simple type.

pub fn is_aggregate(&self) -> bool

Returns true if this is an aggregate type.

pub fn is_member(&self) -> bool

Returns true if this is a member type.