pub struct TraitMap { /* private fields */ }Expand description
A map of traits keyed by their Shape ID.
This provides efficient lookup of traits during serialization and deserialization.
Implementations